#
# spec file for package cecilia
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cecilia
Version:        5.4.1
Release:        2.5
Summary:        Sound synthesis and audio signal processing environment
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            http://ajaxsoundstudio.com/software/cecilia/
Source:         http://ajaxsoundstudio.com/downloads/Cecilia5_%{version}-src.tar.bz2
#PATCH-FIX-OPENSUSE cecilia-setup.patch
Patch0:         %{name}-setup.patch
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       python3-numpy
Requires:       python3-pyo >= 1.0.0
Requires:       python3-wxPython >= 4.1.0
BuildArch:      noarch

%description
Cecilia is a graphic user interface for the sound synthesis and sound
processing package CSound. Cecilia enables the user to build very
quickly graphic interfaces with sliders and curves to control CSound
instruments. It is also an editor to CSound with syntax highlighting
and a built-in reference. It is also a great tool to explore the parameters
of a new opcode in an interactive and intuitive way.

Cecilia uses the pyo audio engine created for the Python programming language.

Cecilia was designed by and for musicians and sound designers. All
the traditional sound processing devices are included such as EQs,
compressors and delays adapted for the most simple applications and
the wildest imaginable sonic contortions.

%prep
%autosetup -p1 -n Cecilia5_%{version}-src

%build
%python3_build

%install
%python3_install
for s in 16 32 48 64 96 128 192 256 512; do
  mkdir -pv %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps
  convert -strip -resize ${s} scripts/Cecilia5_512.png %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/%{name}.png
done
mv %{buildroot}%{_bindir}/Cecilia5.py %{buildroot}%{_bindir}/%{name}
%suse_update_desktop_file -c %{name} %{name} "Sound synthesis and audio signal processing environment" %{name} %{name} "Audio;AudioVideoEditing;"
%fdupes %{buildroot}%{python3_sitelib}

%files
%doc README.rst whatsnew.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.4.1
  * Support WxPython version 4.1.0.
  * Support pyo version 1.0.3.
  * Removed presets from cecilia5 files.
    Moved them to ~/.cecilia5/presets folder
  * Added filter per grain in StochGrains.c5 an StochGrains2.c5
  * Allow the user to add a point on a line, without alteration,
    with Shift-Click.
  * NEW MODULE: AutoModFilter – Filter auto-modulated by an audio
    feature of its input sound
  * NEW MODULE: Binaural – Binaural 3D spatialization
  * NEW MODULE: MatrixReverb – Delay-line rotating-matrix reverb
  * NEW MODULE: StateVar2 – State Variable Filter with user-defined
    filter types
  * NEW MODULE: Stutterer – Read segments extracted from a sound
    loaded in memory
  * NEW MODULE: WaveScanSynth – Synthesis where the waveform is a
    small portion extracted from an audio signal
- Updated cecilia-setup.patch
* Sat Nov 23 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Use convert -strip to not include build time in png (boo#1047218)
* Sat Nov 16 2019 Luigi Baldoni <aloisio@gmx.com>
- Software entirely rewritten in python
  version 5.3.5:
  * Upgraded to python version 3.6.4, wxPython-4.0.1 and pyo
    0.9.0.
  * Better error handling when loading or running a cecilia5
    module.
  version 5.3.4:
  * Upgraded to python version 3.6.3, wxPython-4.0.0b2 and pyo
    0.8.8.
  * Fixed preferences path encoding on Windows.
  * Fixed unicode paths on MacOS when running as an application.
  version 5.3.3:
  * Upgraded to python version 3.6.2, wxPython-4.0.0b1 and pyo
    0.8.7.
  version 5.3.2:
  * Build against wxPython-4.0.0a2.
  version 5.3.1:
  * Better handling of non-ascii characters in preferences file.
  * Fixed standalone packaging on OSX.
  * Fixed curved line not showing on module initialization.
  * UltimateGrainer now allows a grain duration up to 10 seconds.
  version 5.3.0:
  * Migration of the application code to python3 and wxpython
    3.0.3 (phoenix) completed.
  * Source code cleanup (refactoring, removed dead and/or
    duplicated code).
  * Lot of fixed bugs.
  * Automatic saving of the module after creating or deleting a
    preset.
  * Warning to save on quit.
  * The app now opens with the last used module (instead of the
    random chooser).
  * Revisited tooltip and html documentation.
  * On Windows, default preferences for input/output devices
    should be set to WASAPI devices.
  * Added ChenLee attractor to the ChaosMod plugin.
  * Added various modulation waveforms to BinModulator.c5
  * All modules have been tested and cleaned.
    New modules:
  * UltimateGrainer - A state-of-the-art granulation processing
    module.
  * RandomAccumulator - Variable speed recording accumulator
    module.
  * UpDistoRes - Arctangent distortion module with upsampling
    and resonant lowpass filter.
  version 5.0.8:
  * Record button now records in realtime (offline rendering is
    now triggered with Menubar->Action->Bounce to Disk.
  * User can set the starting point by moving the cursor above
    the grapher.
  * Drag and Drop file or folder on the input sound popup to
    loads sounds.
  * Right-click on sound popup opens a "Recent audio files"
    popup.
  * Sliders can be controlled with MIDI or Open Sound Control
    messages.
  * When moving a point on the graph, Alt key clipped the
    position on the horizontal axis while Shift-Alt keys clipped the
    position on the vertical axis.
  * Added two batch processing modes. Either every presets
    applied on the selected sound, or the current preset applied to
    every sounds in the folder.
  * Midi notes are automatically assigned to the sampler
    transposition and controller 7 to the master gain. Must be
    activated in the preferences.
  version 5.0.7:
  * Disabled duration slider while playing.
  * Fixed segmentation fault on preset changes.
  * Added a DropFileTarget on the Grapher (for .c5 or .py files).
  * Fixed opening soundfile player/editor on Windows and OSX.
  * Changed delay time before a popup close itself (when loosing
    focus) from 500 ms to 1000 ms.
  version 5.0.6:
  * Fixed memory leak occuring on each run play/stop (need pyo
    [revision
    974](https://code.google.com/p/cecilia5/source/detail?r=974)).
  * Allow fraction notation in cgen (list entry in the
    interface).
  version 5.0.5:
  * Disabled printing sound info for all sounds in the selected
    folder.
  * Added new filter module, Vocoder. (need pyo to be up-to-date
    with sources).
  * Fixed wrong executable path generated by py2app (OSX app).
  * Removed Jack and Coreaudio from driver's list in bundled app
    on OSX (leaved them when running from sources).
  * Fixed bug: The red button doesn't turn off at the end of
    recording.
  * cgen ignores trailing coma in poup entry.
  * Fixed bug: Do not quiery for the control panel if the
    interface doesn't exist yet.
  * Fixed bug in ListEntry widget when loading from a preset.
  version 5.0.3:
  * List in cgen popup window can now be entered as 'comma' or
    'space' separated values.
  * Fixed number of channels used by the audio Server.
  * Wait for the audio Server releasing soundcard's stream
    before allowing to play again.
  * Fixed saving .c5 file on Windows.
  * Added 2 filter modules: BrickWall.c5 and BandBrickWall.c5.
  version 5.0.2:
  * Automatically save a preset named "last save" when saving a
    module. On module loading, if "last save" preset exists, it is
    activated.
  * Fixed display of the Channels menu.
  * Fixed bugs in sliders automation recording.
  version 5.0.1:
  * Fixed audio input/output selection.
  * Fixed BaseModule.addSampler "pitch" argument.
  version 5.0.0:
  * First beta release.
- Dropped cecilia-path-fix.dif and cecilia-CVE-2008-1832.patch
  (they no longer apply to new codebase)
- Added cecilia-setup.patch (courtesy of debian)
- Spec cleanup
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Sep 17 2008 vgorobets@suse.de
- added %%fdupes macro, because the package contained some
  duplicate files
* Wed May 21 2008 max@suse.de
- Remove bogus version check that handled temp files insecurely
  (bnc#380502, CVE-2008-1832).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Feb  4 2004 hmacht@suse.de
- added option # norootforbuild in specfile
* Tue Jul  8 2003 tiwai@suse.de
- initial version: 2.0.5.
